Derive Macro mutable::Mutable

source ·
#[derive(Mutable)]
Generate the implementation for the Mutable trait

May only be used on enums Requires that all fields implements Mutable

The mutation type is an enum, for which each variant correspond to a field of the struct. Each of them as only one element, which is the mutation type of the attribute type (see Mutable)